@@ -1,30 +1,30 @@
 #' Interface to \pkg{shinystan}
-#' 
+#'
 #' Provide an interface to \pkg{shinystan} for models fitted with \pkg{brms}
-#' 
+#'
 #' @aliases launch_shinystan
-#' 
+#'
 #' @param object A fitted model object of class \code{brmcoda}.
-#' @param ... Optional arguments to pass to 
+#' @param ... Optional arguments to pass to
 #' \code{\link{launch_shinystan.brmsfit}} or \code{\link[shiny:runApp]{runApp}}.
 #'
 #' @seealso \code{\link[shinystan:launch_shinystan]{launch_shinystan}}
-#' 
+#'
 #' @return An S4 shinystan object
-#' 
+#'
 #' @method launch_shinystan brmcoda
-#' @importFrom brms launch_shinystan
+#' @importFrom shinystan launch_shinystan
 #' @export
 launch_shinystan.brmcoda <- function(object, ...) {
-  launch_shinystan(object$Model, ...)
+  launch_shinystan(object$model, ...)
 }
 
 #' multilevelcoda Simulation Study Results
-#' 
+#'
 #' Provide the full results for a simulation study testing the performance of \pkg{multilevelcoda}
-#' 
+#'
 #' @return An S4 shiny object
-#' 
+#'
 #' @importFrom plotly plotlyOutput
 #' @importFrom plotly renderPlotly
 #' @importFrom shiny br
@@ -59,21 +59,21 @@ launch_shinystan.brmcoda <- function(object, ...) {
 #' @importFrom utils data
 #' @export
 multilevelcoda_sim <- function() {
-  
+
   # shiny input
   sim <- data(sim, envir = environment())
-  
+
   brmcoda_tab <- sim[["brmcoda_tab"]]
   sub_tab <- sim[["sub_tab"]]
-  
+
   brmcoda_d3 <- sim[["brmcoda_plot"]][["brmcoda_d3"]]
   brmcoda_d4 <- sim[["brmcoda_plot"]][["brmcoda_d4"]]
   brmcoda_d5 <- sim[["brmcoda_plot"]][["brmcoda_d5"]]
-  
+
   sub_d3 <- sim[["sub_plot"]][["sub_d3"]]
   sub_d4 <- sim[["sub_plot"]][["sub_d4"]]
   sub_d5 <- sim[["sub_plot"]][["sub_d5"]]
-  
+
   ## theme
   shinyOptions(bslib = TRUE)
   theme <- bs_theme(
@@ -83,7 +83,7 @@ multilevelcoda_sim <- function() {
     fg = "#1C1718",
     primary = "#90766B",
     secondary = "#A1B2C2",
-    success = "#708885", 
+    success = "#708885",
     info = "#b76e79",
     warning = "#FAD899",
     danger = "#944C4C",
@@ -104,59 +104,59 @@ multilevelcoda_sim <- function() {
       "navbar-light-bg" = "#665C58", #90766B
       "navbar-default-link-hover-bg" = "#708885",
       "navbar-light-panel-bg" = "#A1B2C2",
-      
-      "table-bg" = "#EFE3E0",   #E5E8E1 DFD7D6 
-      "table-accent-bg" = "#fff", 
+
+      "table-bg" = "#EFE3E0",   #E5E8E1 DFD7D6
+      "table-accent-bg" = "#fff",
       "table-light-striped-bg" = "#FAF7F3",
       "table-light-striped-bg-active" = "#CFDAE2",
       "table-bg-hover" = "#DFD7D6",
-      
+
       "pagination-color" = "#3d251e",
       "pagination-bg" = "#BEC7B4",
       "pagination-border-color" = "#BEC7B4",
-      
+
       "pagination-hover-colour" = "#FAF7F3",
       "pagination-hover-bg" = "#708885",
       "pagination-hover-border-color" = "#708885",
-      
+
       "pagination-active-bg" = "#8DA290",
       "pagination-active-border-color" = "#8DA290",
-      
-      "pagination-disabled-bg" = "#5A6367", 
+
+      "pagination-disabled-bg" = "#5A6367",
       "pagination-disabled-border-color" = "#5A6367",
       "pagination-disabled-color" = "#708885",
-      
+
       "navbar-light-table-striped-color" = "#1C1718",
       "navbar-light-table-striped-bg" = "#CFDAE2",
       "navbar-light-table-hover-bg" = "#CFDAE2",
-      
+
       "dropdown-bg" = "#fff",
-      
+
       # "table-striped-bg" = "#FAF7F3",
       # "table-hover-bg-factor" = "1.25",
       "btn-default-bg" = "#A1B2C2",
       "btn-success-bg" = "#A1B2C2",
       "input-bg" = "#fff",
-      
-      
+
+
       "legend-color" = "#DCD5CE",
       "border-primary" = "#3d251e",
       "bg-primary" = "#3d251e",
-      
-      
-      
+
+
+
       "table-active-bg" = "#F0DBDE  !important"
       # "bs-table-hover-bg" = "#CFDAE2",
-      # 
+      #
       # "bs-table-bg-accent" = "#CFDAE2"
-      
+
       # "inverse-bg" = "#DCD5CE"
-      
+
     )
-  
+
   # shiny server  ----------------------
   server <- function(input, output, session) {
-    
+
     # Summary Statistics -------------------
     ## brmcoda tab ---------------
     output$simsum_brmcoda_table <- DT::renderDataTable(DT::datatable({
@@ -205,7 +205,7 @@ multilevelcoda_sim <- function() {
       if (input$D_brmcoda != "All") {
         brmcoda_tab <- brmcoda_tab[D == input$D_brmcoda]
       }
-      
+
       brmcoda_tab <-
         brmcoda_tab[by %in% par_brmcoda &
                       Stat == input$stat_brmcoda, .(Stat,
@@ -217,11 +217,11 @@ multilevelcoda_sim <- function() {
                                                     # sd_ID_Intercept,
                                                     sigma,
                                                     OnTarget)]
-      
+
       # brmcoda_tab[] <- lapply(brmcoda_tab, function(x) if(is.numeric(x)) round(x, 2) else x)
-      
+
       brmcoda_tab
-      
+
     }, options = list(
       info = T,
       searching = T,
@@ -229,10 +229,10 @@ multilevelcoda_sim <- function() {
       autoWidth = F,
       scrollX = T
     )))
-    
+
     ## substitution tab ------------
     output$simsum_sub_table <- DT::renderDataTable(DT::datatable({
-      
+
       if (input$rint_sd_sub == "medium" & input$res_sd1_sub == "medium") {
         sub_tab <- sub_tab[condition == "base"]
       } else if (input$rint_sd_sub == "medium" & input$res_sd1_sub == "small") {
@@ -265,7 +265,7 @@ multilevelcoda_sim <- function() {
       } else if (input$level_sub == "Within") {
         sub_tab <- sub_tab[Level == "within"]
       }
-      
+
       sub_tab <-
         sub_tab[Stat == input$stat_sub, .(Stat,
                                           Estimates,
@@ -276,11 +276,11 @@ multilevelcoda_sim <- function() {
                                           # sd_ID_Intercept,
                                           sigma,
                                           OnTarget)]
-      
+
       # sub_tab[] <- lapply(sub_tab, function(x) if(is.numeric(x)) round(x, 2) else x)
-      
+
       sub_tab
-      
+
     }, options = list(
       info = T,
       searching = T,
@@ -288,13 +288,13 @@ multilevelcoda_sim <- function() {
       autoWidth = F,
       scrollX = T
     )))
-    
+
     # Summary Plots -------------------
     # ranges_brmcoda <- reactiveValues(x = NULL, y = NULL)
-    
+
     ## brmcoda plot ---------------
     output$simsum_brmcoda_plot <- renderPlotly({
-      
+
       if (input$rint_sd_brmcoda_plot == "medium" & input$res_sd1_brmcoda_plot == "medium") {
         if (input$D_brmcoda_plot == 3) {
           .par_plot(brmcoda_d3[Stat == input$stat_brmcoda_plot & condition == "base"], shiny = TRUE)
@@ -323,7 +323,7 @@ multilevelcoda_sim <- function() {
         if (input$D_brmcoda_plot == 3) {
           .par_plot(brmcoda_d3[Stat == input$stat_brmcoda_plot & condition == "REsmall_RESlarge"], shiny = TRUE)
         } else if (input$D_brmcoda_plot == 4) {
-          .par_plot(brmcoda_d4[Stat == input$stat_brmcoda_plot & condition == "REsmall_RESlarge"], shiny = TRUE) 
+          .par_plot(brmcoda_d4[Stat == input$stat_brmcoda_plot & condition == "REsmall_RESlarge"], shiny = TRUE)
         } else if (input$D_brmcoda_plot == 5) {
           .par_plot(brmcoda_d5[Stat == input$stat_brmcoda_plot & condition == "REsmall_RESlarge"], shiny = TRUE)
         }
@@ -336,12 +336,12 @@ multilevelcoda_sim <- function() {
           .par_plot(brmcoda_d5[Stat == input$stat_brmcoda_plot & condition == "RElarge_RESsmall"], shiny = TRUE)
         }
       }
-      
+
     })
-    
+
     ## substitution plot ---------------
     output$simsum_sub_plot <- renderPlotly({
-      
+
       if (input$rint_sd_sub_plot == "medium" & input$res_sd1_sub_plot == "medium") {
         if (input$D_sub_plot == 3) {
           .par_plot(sub_d3[Stat == input$stat_sub_plot & condition == "base"], shiny = TRUE)
@@ -383,17 +383,17 @@ multilevelcoda_sim <- function() {
           .par_plot(sub_d5[Stat == input$stat_sub_plot & condition == "RElarge_RESsmall"], shiny = TRUE)
         }
       }
-      
+
     })
-    
+
     output$coda <- renderImage({
       filename <- normalizePath(file.path('./inst',
                                           paste('coda.png')))
-      
+
       # Return a list containing the filename and alt text
       list(src = filename,
            heigh = "40px", width = "50px")
-      
+
     }, deleteFile = FALSE)
     # observe(session$setCurrentTheme(
     #   if (isTRUE(input$dark_mode)) dark else light
@@ -403,15 +403,15 @@ multilevelcoda_sim <- function() {
     #   if (!is.null(brush)) {
     #     ranges_brmcoda$x <- c(brush$xmin, brush$xmax)
     #     ranges_brmcoda$y <- c(brush$ymin, brush$ymax)
-    #     
+    #
     #   } else {
     #     ranges_brmcoda$x <- NULL
     #     ranges_brmcoda$y <- NULL
     #   }
     # })
-    
+
   }
-  
+
   # shiny ui -----------------
   ui <- fluidPage(
     theme = floras,
@@ -459,14 +459,14 @@ multilevelcoda_sim <- function() {
     br(),
     br(),
     br(),
-    
+
     # headerPanel(title = span(img(src = "multilevelcoda-sims-shiny/www/coda.png", height = 35), "test")),
-    
+
     # .tabs-above > .nav > li[class=active] > a {
     #   background-color: #6171a9;
     #     color: #FFF;
     # }
-    
+
     # .dataTables_wrapper .dataTables_length {
     #   float: right;}
     # .dataTables_wrapper .dataTables_filter {
@@ -477,7 +477,7 @@ multilevelcoda_sim <- function() {
     # theme = shiny::bootstrapLib(),
     # tags$head(includeCSS("multilevelcoda-sim-shiny/www/florastheme.css")),
     # checkboxInput("dark_mode", "Dark mode", FALSE),
-    
+
     navbarPage(
       theme = floras,
       position = "fixed-top",
@@ -489,20 +489,20 @@ multilevelcoda_sim <- function() {
       nav_menu(
         "Summary Statistics",
         # icon = icon("table"),
-        
+
         ### brmcoda ------------------
         nav_panel(
           "Bayesian Compositional Multilevel",
           fluid = TRUE,
           # titlePanel("Simulation Condition"),
-          
+
           sidebarLayout(
             sidebarPanel(
               width = 3,
               style = "height:740px",
               h5("Simulation Condition"),
               br(),
-              
+
               selectInput("N_brmcoda",
                           "Number of individuals (N):",
                           c("All",
@@ -591,7 +591,7 @@ multilevelcoda_sim <- function() {
             )
           )
         ),
-        
+
         ### substitution ------------------
         nav_panel(
           "Bayesian Compositional Multilevel Substitution",
@@ -604,7 +604,7 @@ multilevelcoda_sim <- function() {
               style = "height:740px",
               h5("Simulation Condition"),
               br(),
-              
+
               selectInput("N_sub",
                           "Number of individuals (N):",
                           c("All",
@@ -651,7 +651,7 @@ multilevelcoda_sim <- function() {
             ),
             mainPanel(
               width = 9,
-              
+
               fluidRow(column(
                 12,
                 selectInput(
@@ -667,7 +667,7 @@ multilevelcoda_sim <- function() {
                   width = "100%"
                 )
               )),
-              
+
               fluidRow(
                 column(
                   6,
@@ -740,31 +740,31 @@ multilevelcoda_sim <- function() {
             )
           )
         )
-        
-        
+
+
       ),
       ## Simulation Plots -----------------------------
       nav_menu(
         "Summary Plots",
         # icon = icon("chart-line", lib = "font-awesome"),
-        
+
         ### brmcoda plots ------------------
         nav_panel(
           "Bayesian Compositional Multilevel Parameters",
           fluid = TRUE,
-          
+
           sidebarLayout(
             sidebarPanel(
               width = 3,
               style = "height:740px",
               h5("Simulation Condition"),
               br(),
-              
+
               selectInput(
                 "N_brmcoda_plot",
                 "Number of individuals (N):",
                 c("All"
-                  # , 
+                  # ,
                   # 30, 50, 360, 1200
                 )
               ),
@@ -782,7 +782,7 @@ multilevelcoda_sim <- function() {
                 inline = TRUE,
                 width = "100%"
               ),
-              
+
               selectInput(
                 "rint_sd_brmcoda_plot",
                 "Random Intercept variance:",
@@ -819,7 +819,7 @@ multilevelcoda_sim <- function() {
             ),
             mainPanel(
               width = 9,
-              
+
               fluidRow(column(
                 12,
                 selectInput(
@@ -835,7 +835,7 @@ multilevelcoda_sim <- function() {
                   width = "100%"
                 )
               )),
-              
+
               fluidRow(column(
                 12,
                 selectInput(
@@ -865,20 +865,20 @@ multilevelcoda_sim <- function() {
             )
           )
         ),
-        
+
         ### substitution plots ------------------
         nav_panel(
           "Bayesian Compositional Multilevel Substitution Estimates",
           fluid = TRUE,
           # icon = icon("arrow-right-arrow-left", lib = "font-awesome"),
-          
+
           sidebarLayout(
             sidebarPanel(
               width = 3,
               style = "height:740px",
               h5("Simulation Condition"),
               br(),
-              
+
               selectInput(
                 "N_sub_plot",
                 "Number of individuals (N):",
@@ -900,7 +900,7 @@ multilevelcoda_sim <- function() {
                 inline = TRUE,
                 width = "100%"
               ),
-              
+
               selectInput(
                 "rint_sd_sub_plot",
                 "Random Intercept variance:",
@@ -932,7 +932,7 @@ multilevelcoda_sim <- function() {
             ),
             mainPanel(
               width = 9,
-              
+
               fluidRow(column(
                 12,
                 selectInput(
@@ -948,7 +948,7 @@ multilevelcoda_sim <- function() {
                   width = "100%"
                 )
               )),
-              
+
               fluidRow(
                 column(
                   6,
@@ -1007,7 +1007,7 @@ multilevelcoda_sim <- function() {
                     "level_sub_plot",
                     "Level:",
                     c("All"
-                      # , 
+                      # ,
                       # "Between", "Within"
                     ),
                     selected = "All",
@@ -1024,16 +1024,16 @@ multilevelcoda_sim <- function() {
           )
         )
       ),
-      
+
       nav_spacer(),
       # nav_item(icon = icon("arrow-right-arrow-left", lib = "font-awesome")),
       nav_item(imageOutput("coda", height = "50px"), fillable = FALSE),
-      
-      
+
+
     )
   )
   # run app ------------------------
   shinyApp(ui = ui, server = server)
-  
-  
-}
\ No newline at end of file
+
+
+}
